@@ -19,7 +19,7 @@ use Exporter;
 
 use constant PROGRAM => 'trepan.pl';
 use version;
-$VERSION='0.72'; # To fool CPAN indexer. Is <= real version
+$VERSION='0.73'; # To fool CPAN indexer. Is <= real version
 $VERSION = $Devel::Trepan::Version::VERSION;
 $PROGRAM = PROGRAM;
 
@@ -27,6 +27,12 @@ sub show_version() {
     PROGRAM . ", version $Devel::Trepan::VERSION";
 }
 
+# Access to stopping point as an integer.
+sub addr() { $DB::OP_addr };
+
+# Access to stopping point as a hex string.
+sub haddr() { sprintf "0x%x", $DB::OP_addr }
+
 # =head2 debugger
 # Allows program to make an explicit call to the debugger.
 # B<Example:>
@@ -103,7 +109,7 @@ L<trepanning debuggers|http://github.com/rocky/rb-trepanning/wiki>.
 
 =item *
 
-extensive pod-formmated online-help
+extensive pod-formatted online-help
 
 =item *
 
@@ -329,10 +335,6 @@ L<Cancel some expressions to be displayed when program stops
 
 =item *
 
-L<Deparse source code via B::DeparseTree (deparse)|Devel::Trepan::CmdProcessor::Command::Deparse>
-
-=item *
-
 L<Invoke an editor on some source code (edit)|Devel::Trepan::CmdProcessor::Command::Edit>
 
 =item *
@@ -640,8 +642,8 @@ use some parts of this along with C<perl5db>.
 L<Devel::Hdb>
 
 A Perl debugger that uses HTML and javascript to implement the
-GUI. The front end talks via a REST service. It too uses ideas from
-L<DB>.
+GUI. The front end talks via a REST service. (via Websocket would be
+cooler though.) It too uses ideas from L<DB>.
 
 =back
 
