@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012, 2014 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2012, 2014-2015 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine'; no warnings 'once';
 use rlib '../../../../..';
 use strict;
@@ -44,20 +44,17 @@ HELP
 unless (caller) {
     # Demo it.
     # FIXME: DRY with other subcommand manager demo code.
-    require Devel::Trepan::CmdProcessor;
-    my $proc = Devel::Trepan::CmdProcessor->new;
-    my $parent = Devel::Trepan::CmdProcessor::Command::Set->new($proc, 'set');
-    my $cmd = __PACKAGE__->new($parent, 'display');
-    print $cmd->{help}, "\n";
-    print "min args: ", $cmd->MIN_ARGS, "\n";
+    require Devel::Trepan::CmdProcessor::Mock;
+    my ($proc, $cmd) =
+	Devel::Trepan::CmdProcessor::Mock::subcmd_setup();
+    Devel::Trepan::CmdProcessor::Mock::subcmd_demo_info($proc, $cmd);
     for my $arg ('ev', 'op', 'foo') {
         my @aref = $cmd->complete_token_with_next($arg);
         printf "%s\n", @aref ? $aref[0]->[0]: 'undef';
     }
-
-    print join(' ', @{$cmd->{prefix}}), "\n";
     $cmd->run($cmd->{prefix});
-    # $cmd->run($cmd->{prefix}, ('except', 'on'));
+    my @args = (@{$cmd->{prefix}}, 'op', 'on');
+    $cmd->run(\@args);
 }
 
 1;
